@@ -71,8 +71,6 @@ void usage(char *progname)
 int is_mounted(char *path)
 {
     FILE *f;
-    char targetpath1[PATH_MAX], targetpath2[PATH_MAX];
-
     struct mntent *entry;
 
     if (!(f = fopen("/proc/mounts", "r"))) {
@@ -81,9 +79,7 @@ int is_mounted(char *path)
     }
 
     while ((entry = getmntent(f)) != NULL) {
-        realpath(path, targetpath1);
-        realpath(entry->mnt_dir, targetpath2);
-        if (!strcmp(targetpath1, targetpath2)) {
+        if (!strcmp(path, entry->mnt_dir)) {
             /* OK, here's where things get a little odd.  We want to make sure
              * that the mount is owned by the user.  Normally, we'd do a stat
              * call here, but because we're a setuid program, and fuse by
@@ -115,7 +111,7 @@ int is_mounted(char *path)
 
 void mkdir_safe(char *dir)
 {
-    if (mkdir(dir, 0750)) {
+    if (mkdir(dir, 0700)) {
         if (errno == EEXIST) {
             /* OK, we've been told that this already exists.  Make sure
              * nothing's mounted on top of it, so we aren't doing something
@@ -131,6 +127,11 @@ void mkdir_safe(char *dir)
             exit(1);
         }
     }
+    if (chown (dir, uidReal, 0)) {
+	perror ("Unable to change owner of directory");
+	rmdir (dir);
+	exit (1);
+    }
 }
 
 /*
@@ -157,7 +158,7 @@ int root_mounter(const char *path1, const char *path2)
             execle(mountprog, mountprog, "--move", path1, path2, NULL,
                    null_env);
         else
-            execle(umountprog, umountprog, path1, NULL, null_env);
+            execle(umountprog, umountprog, "-l", path1, NULL, null_env);
         perror("Error: execl() returned");
         exit(1);                                 /* exec should never return */
     } else if (child > 0) {
