@@ -128,6 +128,10 @@ void ltspfs_dispatch(int sockfd, XDR * in)
     if (debug)
         info("Packet type: %s\n", ltspfs_opcode_str[packet_type]);
 
+    if (noauth) {
+        authenticated++;
+    }
+
     if (!authenticated) {                        /* Haven't authenticated yet */
         switch (packet_type) {
         case LTSPFS_XAUTH:
@@ -963,6 +967,9 @@ void handle_auth(int sockfd, XDR * in)
 {
     char recdtoken[64];
     size_t auth_size;
+    char authtoken[64];
+    ssize_t authtokensize;
+    int authfile, i;
 
     /*
      * Get our auth size.
@@ -982,34 +989,28 @@ void handle_auth(int sockfd, XDR * in)
 
     recdtoken[auth_size] = '\0';
 
-    if (!noauth) {
-        char authtoken[64];
-        ssize_t authtokensize;
-        int authfile, i;
+    /*
+     * Test our authentication.
+     * our XAUTHORITY environment variable is pointing to the xauth record,
+     * so if we've got a match, we the open should succeed.
+     */
 
-        /*
-         * Test our authentication.
-         * our XAUTHORITY environment variable is pointing to the xauth record,
-         * so if we've got a match, we the open should succeed.
-         */
+    authfile = open("/var/run/ltspfs_token", O_RDONLY);
+    if (authfile < 0) {
+        eacces(sockfd);
+        return;
+    }
 
-        authfile = open("/var/run/ltspfs_token", O_RDONLY);
-        if (authfile < 0) {
-            eacces(sockfd);
-            return;
-        }
+    authtokensize = read(authfile, authtoken, sizeof authtoken);
+    close(authfile);
 
-        authtokensize = read(authfile, authtoken, sizeof authtoken);
-        close(authfile);
+    for (i = 0; i < authtokensize; i++)
+        if (authtoken[i] == '\n')
+            authtoken[i] = '\0';
 
-        for (i = 0; i < authtokensize; i++)
-            if (authtoken[i] == '\n')
-                authtoken[i] = '\0';
-
-        if (strncmp(authtoken, recdtoken, auth_size)) {
-            eacces(sockfd);
-            return;
-        }
+    if (strncmp(authtoken, recdtoken, auth_size)) {
+        eacces(sockfd);
+        return;
     }
 
     status_return(sockfd, OK);                   /* Acknowledge auth */
